# CORE modules

This directory contains modules that are fundamental to many other packages and modules. The difference between
core and common modules is that the common modules can typically be replaced by custom replacements that
are project specific. The core modules SHOULD NOT be customised and should be seen as a mandatory prerequisite for
other modules relying on them.
